@@ -1,6 +1,6 @@
 use crate::config;
 use crate::events::{Event, EventManager};
-use crate::playable::Playable;
+use crate::model::playable::Playable;
 use crate::queue::QueueEvent;
 use crate::spotify::PlayerEvent;
 use futures::channel::oneshot;
@@ -64,6 +64,13 @@ impl Worker {
     }
 }
 
+impl Drop for Worker {
+    fn drop(&mut self) {
+        debug!("Worker thread is shutting down, stopping player");
+        self.player.stop();
+    }
+}
+
 impl Worker {
     fn get_token(
         &self,
